@@ -35,34 +35,34 @@ public:
     explicit LdapStructureProxyModel(QObject *parent = nullptr);
     ~LdapStructureProxyModel() override;
 
-    QVariant data(const QModelIndex &index, int role) const override;
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role) const override;
     /**
      * Reimplemented from QAbstractItemModel::setData(). This is a placeholder for when
      * LdapStructureProxyModel beomes writeable and always returns false.
      */
-    bool setData(const QModelIndex &index,
+    Q_REQUIRED_RESULT bool setData(const QModelIndex &index,
                  const QVariant &value,
                  int role = Qt::EditRole) override;
-    bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
-    QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
-    int columnCount(const QModelIndex &parent) const override;
-    Qt::ItemFlags flags(const QModelIndex &index) const override;
-    bool hasChildren(const QModelIndex &parent) const override;
+    Q_REQUIRED_RESULT bool filterAcceptsRow(int sourceRow, const QModelIndex &sourceParent) const override;
+    Q_REQUIRED_RESULT QVariant headerData(int section, Qt::Orientation orientation, int role) const override;
+    Q_REQUIRED_RESULT int columnCount(const QModelIndex &parent) const override;
+    Q_REQUIRED_RESULT Qt::ItemFlags flags(const QModelIndex &index) const override;
+    Q_REQUIRED_RESULT bool hasChildren(const QModelIndex &parent) const override;
 
-    QModelIndex mapFromSource(const QModelIndex &sourceIndex) const override;
-    QModelIndex mapToSource(const QModelIndex &proxyIndex) const override;
+    Q_REQUIRED_RESULT QModelIndex mapFromSource(const QModelIndex &sourceIndex) const override;
+    Q_REQUIRED_RESULT QModelIndex mapToSource(const QModelIndex &proxyIndex) const override;
 
     /**
      * Reimplemented from QAbstractItemModel::insertRows(). This is a placeholder for when
      * LdapStructureProxyModel beomes writeable and always returns false.
      */
-    bool insertRows(int row, int count,
+    Q_REQUIRED_RESULT bool insertRows(int row, int count,
                     const QModelIndex &parent = QModelIndex()) override;
     /**
      * Reimplemented from QAbstractItemModel::removeRows(). This is a placeholder for when
      * LdapStructureProxyModel beomes writeable and always returns false.
      */
-    bool removeRows(int row, int count,
+    Q_REQUIRED_RESULT bool removeRows(int row, int count,
                     const QModelIndex &parent = QModelIndex()) override;
     /**
      * Reimplemented from QAbstractItemModel::removeRows(). The default implementation
@@ -76,17 +76,17 @@ public:
      * Reimplemented from QAbstractItemModel::supportedDropActions(). The default
      * implementation returns Qt::MoveAction.
      */
-    Qt::DropActions supportedDropActions() const override;
+    Q_REQUIRED_RESULT Qt::DropActions supportedDropActions() const override;
     /**
      * Reimplemented from QAbstractItemModel::mimedata(). This is a placeholder for when
      * LdapStructureProxyModel beomes writeable and always returns 0.
      */
-    QMimeData *mimeData(const QModelIndexList &indexes) const override;
+    Q_REQUIRED_RESULT QMimeData *mimeData(const QModelIndexList &indexes) const override;
     /**
      * Reimplemented from QAbstractItemModel::dropMimedata(). This is a placeholder for when
      * LdapStructureProxyModel beomes writeable and always returns false.
      */
-    bool dropMimeData(const QMimeData *data, Qt::DropAction action,
+    Q_REQUIRED_RESULT bool dropMimeData(const QMimeData *data, Qt::DropAction action,
                       int row, int column, const QModelIndex &parent) override;
 };
 
